@@ -12,15 +12,15 @@ import logging
 import numbers
 import sys
 import datetime as dt
-import typing as t
 from collections.abc import Iterable
+from typing import TYPE_CHECKING, Dict, List, Optional, Any, Callable, Tuple, Union
 
-if t.TYPE_CHECKING:
+
+if TYPE_CHECKING:
     from redis import Redis
 
 from redis.exceptions import ResponseError
 
-from .compat import as_text, string_types
 from .exceptions import TimeoutFormatError
 
 logger = logging.getLogger(__name__)
@@ -41,10 +41,8 @@ class _Colorizer:
         self.codes["blink"] = esc + "05m"
         self.codes["overline"] = esc + "06m"
 
-        dark_colors = ["black", "darkred", "darkgreen", "brown", "darkblue",
-                       "purple", "teal", "lightgray"]
-        light_colors = ["darkgray", "red", "green", "yellow", "blue",
-                        "fuchsia", "turquoise", "white"]
+        dark_colors = ["black", "darkred", "darkgreen", "brown", "darkblue", "purple", "teal", "lightgray"]
+        light_colors = ["darkgray", "red", "green", "yellow", "blue", "fuchsia", "turquoise", "white"]
 
         x = 30
         for d, l in zip(dark_colors, light_colors):
@@ -90,8 +88,10 @@ def make_colorizer(color: str):
             >>> # You can then use:
             >>> print("It's either " + green('OK') + ' or ' + red('Oops'))
     """
+
     def inner(text):
         return colorizer.colorize(color, text)
+
     return inner
 
 
@@ -126,7 +126,54 @@ class ColorizingStreamHandler(logging.StreamHandler):
         return message
 
 
-def import_attribute(name: str):
+def compact(lst: List[Any]) -> List[Any]:
+    """Excludes `None` values from a list-like object.
+
+    Args:
+        lst (list): A list (or list-like) oject
+
+    Returns:
+        object (list): The list without None values
+    """
+    return [item for item in lst if item is not None]
+
+
+def as_text(v: Union[bytes, str]) -> Optional[str]:
+    """Converts a bytes value to a string using `utf-8`.
+
+    Args:
+        v (Union[bytes, str]): The value (bytes or string)
+
+    Raises:
+        ValueError: If the value is not bytes or string
+
+    Returns:
+        value (Optional[str]): Either the decoded string or None
+    """
+    if v is None:
+        return None
+    elif isinstance(v, bytes):
+        return v.decode('utf-8')
+    elif isinstance(v, str):
+        return v
+    else:
+        raise ValueError('Unknown type %r' % type(v))
+
+
+def decode_redis_hash(h) -> Dict[str, Any]:
+    """Decodes the Redis hash, ensuring that keys are strings
+    Most importantly, decodes bytes strings, ensuring the dict has str keys.
+
+    Args:
+        h (Dict[Any, Any]): The Redis hash
+
+    Returns:
+        Dict[str, Any]: The decoded Redis data (Dictionary)
+    """
+    return dict((as_text(k), h[k]) for k in h)
+
+
+def import_attribute(name: str) -> Callable[..., Any]:
     """Returns an attribute from a dotted path name. Example: `path.to.func`.
 
     When the attribute we look for is a staticmethod, module name in its
@@ -146,7 +193,7 @@ def import_attribute(name: str):
         ValueError: If no module is found or invalid attribute name.
 
     Returns:
-        t.Any: An attribute (normally a Callable)
+        Any: An attribute (normally a Callable)
     """
     name_bits = name.split('.')
     module_name_bits, attribute_bits = name_bits[:-1], [name_bits[-1]]
@@ -190,11 +237,11 @@ def now():
 _TIMESTAMP_FORMAT = '%Y-%m-%dT%H:%M:%S.%fZ'
 
 
-def utcformat(dt: dt.datetime):
+def utcformat(dt: dt.datetime) -> str:
     return dt.strftime(as_text(_TIMESTAMP_FORMAT))
 
 
-def utcparse(string: str):
+def utcparse(string: str) -> dt.datetime:
     try:
         return datetime.datetime.strptime(string, _TIMESTAMP_FORMAT)
     except ValueError:
@@ -202,9 +249,8 @@ def utcparse(string: str):
         return datetime.datetime.strptime(string, '%Y-%m-%dT%H:%M:%SZ')
 
 
-def first(iterable: t.Iterable, default=None, key=None):
-    """
-    Return first element of `iterable` that evaluates true, else return None
+def first(iterable: Iterable, default=None, key=None):
+    """Return first element of `iterable` that evaluates true, else return None
     (or an optional default value).
 
     >>> first([0, False, None, [], (), 42])
@@ -228,6 +274,13 @@ def first(iterable: t.Iterable, default=None, key=None):
     >>> first([1, 1, 3, 4, 5], key=lambda x: x % 2 == 0)
     4
 
+    Args:
+        iterable (t.Iterable): _description_
+        default (_type_, optional): _description_. Defaults to None.
+        key (_type_, optional): _description_. Defaults to None.
+
+    Returns:
+        _type_: _description_
     """
     if key is None:
         for el in iterable:
@@ -241,42 +294,67 @@ def first(iterable: t.Iterable, default=None, key=None):
     return default
 
 
-def is_nonstring_iterable(obj: t.Any) -> bool:
-    """Returns whether the obj is an iterable, but not a string"""
-    return isinstance(obj, Iterable) and not isinstance(obj, string_types)
+def is_nonstring_iterable(obj: Any) -> bool:
+    """Returns whether the obj is an iterable, but not a string
 
+    Args:
+        obj (Any): _description_
 
-def ensure_list(obj: t.Any) -> t.List:
+    Returns:
+        bool: _description_
     """
-    When passed an iterable of objects, does nothing, otherwise, it returns
+    return isinstance(obj, Iterable) and not isinstance(obj, str)
+
+
+def ensure_list(obj: Any) -> List:
+    """When passed an iterable of objects, does nothing, otherwise, it returns
     a list with just that object in it.
+
+    Args:
+        obj (Any): _description_
+
+    Returns:
+        List: _description_
     """
     return obj if is_nonstring_iterable(obj) else [obj]
 
 
 def current_timestamp() -> int:
-    """Returns current UTC timestamp"""
+    """Returns current UTC timestamp
+
+    Returns:
+        int: _description_
+    """
     return calendar.timegm(datetime.datetime.utcnow().utctimetuple())
 
 
 def backend_class(holder, default_name, override=None):
-    """Get a backend class using its default attribute name or an override"""
+    """Get a backend class using its default attribute name or an override
+
+    Args:
+        holder (_type_): _description_
+        default_name (_type_): _description_
+        override (_type_, optional): _description_. Defaults to None.
+
+    Returns:
+        _type_: _description_
+    """
     if override is None:
         return getattr(holder, default_name)
-    elif isinstance(override, string_types):
+    elif isinstance(override, str):
         return import_attribute(override)
     else:
         return override
 
 
-def str_to_date(date_str: t.Optional[str]) -> t.Union[dt.datetime, t.Any]:
+def str_to_date(date_str: Optional[str]) -> Union[dt.datetime, Any]:
     if not date_str:
         return
     else:
         return utcparse(date_str.decode())
 
 
-def parse_timeout(timeout: t.Any):
+def parse_timeout(timeout: Any):
     """Transfer all kinds of timeout format to an integer representing seconds"""
     if not isinstance(timeout, numbers.Integral) and timeout is not None:
         try:
@@ -287,20 +365,25 @@ def parse_timeout(timeout: t.Any):
             try:
                 timeout = int(digit) * unit_second[unit]
             except (ValueError, KeyError):
-                raise TimeoutFormatError('Timeout must be an integer or a string representing an integer, or '
-                                         'a string with format: digits + unit, unit can be "d", "h", "m", "s", '
-                                         'such as "1h", "23m".')
+                raise TimeoutFormatError(
+                    'Timeout must be an integer or a string representing an integer, or '
+                    'a string with format: digits + unit, unit can be "d", "h", "m", "s", '
+                    'such as "1h", "23m".'
+                )
 
     return timeout
 
 
-def get_version(connection: 'Redis'):
+def get_version(connection: 'Redis') -> Tuple[int, int, int]:
     """
     Returns tuple of Redis server version.
     This function also correctly handles 4 digit redis server versions.
 
     Args:
         connection (Redis): The Redis connection.
+
+    Returns:
+        version (Tuple[int, int, int]): A tuple representing the semantic versioning format (eg. (5, 0, 9))
     """
     try:
         # Getting the connection info for each job tanks performance, we can cache it on the connection object
@@ -308,7 +391,7 @@ def get_version(connection: 'Redis'):
             setattr(
                 connection,
                 "__rq_redis_server_version",
-                tuple(int(i) for i in connection.info("server")["redis_version"].split('.')[:3])
+                tuple(int(i) for i in connection.info("server")["redis_version"].split('.')[:3]),
             )
         return getattr(connection, "__rq_redis_server_version")
     except ResponseError:  # fakeredis doesn't implement Redis' INFO command
@@ -316,38 +399,50 @@ def get_version(connection: 'Redis'):
 
 
 def ceildiv(a, b):
-    """Ceiling division. Returns the ceiling of the quotient of a division operation"""
+    """Ceiling division. Returns the ceiling of the quotient of a division operation
+
+    Args:
+        a (_type_): _description_
+        b (_type_): _description_
+
+    Returns:
+        _type_: _description_
+    """
     return -(-a // b)
 
 
-def split_list(a_list: t.List[t.Any], segment_size: int):
+def split_list(a_list: List[Any], segment_size: int):
     """Splits a list into multiple smaller lists having size `segment_size`
 
     Args:
-        a_list (t.List[t.Any]): A list to split
+        a_list (List[Any]): A list to split
         segment_size (int): The segment size to split into
 
     Yields:
         list: The splitted listed
     """
     for i in range(0, len(a_list), segment_size):
-        yield a_list[i:i + segment_size]
+        yield a_list[i : i + segment_size]
 
 
-def truncate_long_string(data: str, max_length: t.Optional[int] = None) -> str:
+def truncate_long_string(data: str, max_length: Optional[int] = None) -> str:
     """Truncate arguments with representation longer than max_length
 
     Args:
         data (str): The data to truncate
-        max_length (t.Optional[int], optional): The max length. Defaults to None.
+        max_length (Optional[int], optional): The max length. Defaults to None.
+
+    Returns:
+        truncated (str): The truncated string
     """
     if max_length is None:
         return data
     return (data[:max_length] + '...') if len(data) > max_length else data
 
 
-def get_call_string(func_name: t.Optional[str], args: t.Any, kwargs: t.Dict[t.Any, t.Any],
-                    max_length: t.Optional[int] = None) -> t.Optional[str]:
+def get_call_string(
+    func_name: Optional[str], args: Any, kwargs: Dict[Any, Any], max_length: Optional[int] = None
+) -> Optional[str]:
     """
     Returns a string representation of the call, formatted as a regular
     Python function invocation statement. If max_length is not None, truncate
@@ -355,8 +450,8 @@ def get_call_string(func_name: t.Optional[str], args: t.Any, kwargs: t.Dict[t.An
 
     Args:
         func_name (str): The funtion name
-        args (t.Any): The function arguments
-        kwargs (t.Dict[t.Any, t.Any]): The function kwargs
+        args (Any): The function arguments
+        kwargs (Dict[Any, Any]): The function kwargs
         max_length (int, optional): The max length. Defaults to None.
 
     Returns:
